@@ -7,9 +7,14 @@ pub enum Cmd<C: Component> {
     Submit(C::Event),
     Chain(C::Msg),
     Task(Pin<Box<dyn Future<Output = Self>>>),
+    Batch(Box<dyn BatchProcess<C>>),
     List(Vec<Self>),
 }
 
+pub trait BatchProcess<C: Component> {
+    fn poll(&mut self) -> Pin<Box<dyn Future<Output = Cmd<C>>>>;
+}
+
 impl<C: Component> Cmd<C> {
     pub fn none() -> Self {
         Self::None
@@ -23,6 +28,9 @@ impl<C: Component> Cmd<C> {
     pub fn task(task: impl Future<Output = Self> + 'static) -> Self {
         Self::Task(Box::pin(task))
     }
+    pub fn batch(batch: impl BatchProcess<C> + 'static) -> Self {
+        Self::Batch(Box::new(batch))
+    }
     pub fn list(cmds: Vec<Self>) -> Self {
         Self::List(cmds)
     }
